==> mgb-0.6.2.tar.gz: captcha.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

        // ================= //
	// captcha.php - 1.1 //
	// ================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");

        // get code from database
        $sql = "SELECT `code` FROM ".$db['prefix']."captcha";
        $link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("Error, Line 36: ".mysql_error());
        mysql_select_db($db['dbname'], $link) or die ("Error, Line 37: ".mysql_error());
	$result = mysql_query($sql, $link) or die ("Error, Line 38: ".mysql_error());

        $captcha = @mysql_fetch_array($result);
        $captcha_code = $captcha['code'];
        
        // randomly choose a background for the captcha
        $captcha_randombg = rand(1, 11);
	$captcha_img = imagecreatefrompng ("images/".$settings['iconset_path']."/captchas/captchabg".$captcha_randombg.".png");

	// The font "akoom.ttf" used in here is copyrighted by http://veredgf.fredfarm.com/.
	// It is NOT released under GNU/GPL. It's Freeware. This means you can use and
	// share it for free but you may NOT sell it!

        $textwidth = (120 - 100);
	$textheight = (40 - 15);
	$textcolor = imagecolorallocate($captcha_img, 115, 115, 115);
	imagettftext($captcha_img, 22, -5, $textwidth, $textheight, $textcolor, "./akoom.ttf", $captcha_code);
	imagepng($captcha_img);	
?>

==> mgb-0.6.3.tar.gz: captcha.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ================= //
	// captcha.php - 1.1 //
	// ================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	require ("config.inc.php");
	require ("functions.inc.php");
	require ("load_settings.inc.php");

	// get code from database
	$sql = "SELECT `code` FROM ".$db['prefix']."captcha";
	$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(captcha.php) Error, line 33: ".mysql_error());
	mysql_select_db($db['dbname'], $link) or die ("(captcha.php) Error, line 34: ".mysql_error());
	$result = mysql_query($sql, $link) or die ("(captcha.php) Error, line 35: ".mysql_error());

	$captcha = @mysql_fetch_array($result);
	$captcha_code = $captcha['code'];

	// randomly choose a background for the captcha
	$captcha_randombg = rand(1, 21);
	$captcha_img = imagecreatefrompng ("images/".$settings['iconset_path']."/captchas/captchabg".$captcha_randombg.".png");

	// The font "akoom.ttf" used in here is copyrighted by http://veredgf.fredfarm.com/.
	// It is NOT released under GNU/GPL. It's Freeware. This means you can use and
	// share it for free but you may NOT sell it!

	$textwidth = (120 - 100);
	$textheight = (40 - 15);
	$textcolor = imagecolorallocate($captcha_img, 115, 115, 115);
	imagettftext($captcha_img, 22, -5, $textwidth, $textheight, $textcolor, "./akoom.ttf", $captcha_code);
	imagepng($captcha_img);	
?>
